@@ -13,7 +13,7 @@
 
 Synchronous::Synchronous(uint timeout)
 {
-  connect(&_timer, TQT_SIGNAL(timeout()), TQT_SLOT(done()));
+  connect(&_timer, TQ_SIGNAL(timeout()), TQ_SLOT(done()));
   if (timeout) _timer.start(timeout, true);
 }
 
