@@ -22,8 +22,8 @@
 Process::State Process::runSynchronously(Base &process, RunActions actions, uint timeout)
 {
   Synchronous sync(timeout);
-  TQObject::connect(&process, TQT_SIGNAL(done(int)), &sync, TQT_SLOT(done()));
-  TQObject::connect(&process, TQT_SIGNAL(requestSynchronousStop()), &sync, TQT_SLOT(done()));
+  TQObject::connect(&process, TQ_SIGNAL(done(int)), &sync, TQ_SLOT(done()));
+  TQObject::connect(&process, TQ_SIGNAL(requestSynchronousStop()), &sync, TQ_SLOT(done()));
   if ( (actions & Start) && !process.start(0) ) return process.state();
   Q_ASSERT( process.isRunning() );
   if ( !sync.enterLoop() ) process.timeoutSlot();
@@ -35,11 +35,11 @@ Process::Base::Base(TQObject *parent, const char *name)
   : TQObject(parent, name), _state(Stopped)
 {
   _process = new TDEProcess(this);
-  connect(_process, TQT_SIGNAL(processExited(TDEProcess *)), TQT_SLOT(exited()));
-  connect(_process, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), TQT_SLOT(receivedStdout(TDEProcess*, char *, int)));
-  connect(_process, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), TQT_SLOT(receivedStderr(TDEProcess*, char *, int)));
+  connect(_process, TQ_SIGNAL(processExited(TDEProcess *)), TQ_SLOT(exited()));
+  connect(_process, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)), TQ_SLOT(receivedStdout(TDEProcess*, char *, int)));
+  connect(_process, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)), TQ_SLOT(receivedStderr(TDEProcess*, char *, int)));
   _timer = new TQTimer(this);
-  connect(_timer, TQT_SIGNAL(timeout()), TQT_SLOT(timeoutSlot()));
+  connect(_timer, TQ_SIGNAL(timeout()), TQ_SLOT(timeoutSlot()));
 }
 
 Process::Base::~Base()
