@@ -28,8 +28,8 @@
 PURL::Http::Http(const TQString &hostname)
   : TQHttp(hostname)
 {
-  connect(this, TQT_SIGNAL(responseHeaderReceived(const TQHttpResponseHeader &)),
-          TQT_SLOT(responseHeaderReceivedSlot(const TQHttpResponseHeader &)));
+  connect(this, TQ_SIGNAL(responseHeaderReceived(const TQHttpResponseHeader &)),
+          TQ_SLOT(responseHeaderReceivedSlot(const TQHttpResponseHeader &)));
 }
 
 //-----------------------------------------------------------------------------
@@ -254,7 +254,7 @@ bool PURL::Base::httpUrlExists(bool *ok) const
   if (ok) *ok = false;
   Http http(_url.host());
   Synchronous sync(500);
-  TQObject::connect(&http, TQT_SIGNAL(done(bool)), &sync, TQT_SLOT(done()));
+  TQObject::connect(&http, TQ_SIGNAL(done(bool)), &sync, TQ_SLOT(done()));
   TQFileInfo info(_url.fileName(false));
   http.head(_url.path());
   if ( !sync.enterLoop() ) return false; // timeout
