@@ -64,7 +64,7 @@ void EditListBox::init(uint nbColumns, TQWidget *view)
 	TDEIconLoader loader;
 	TQIconSet iconset = loader.loadIcon("locationbar_erase", TDEIcon::Toolbar);
 	KPushButton *button = new  KPushButton(iconset, TQString(), this);
-	connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(clearEdit()));
+	connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(clearEdit()));
 	hbox->addWidget(button);
       }
       view->reparent( this, TQPoint(0,0) );
@@ -87,11 +87,11 @@ void EditListBox::init(uint nbColumns, TQWidget *view)
     setButtons(_buttons);
 
     if (m_lineEdit) {
-      connect(m_lineEdit,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(typedSomething(const TQString&)));
+      connect(m_lineEdit,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(typedSomething(const TQString&)));
       m_lineEdit->setTrapReturnKey(true);
-      connect(m_lineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(addItem()));
+      connect(m_lineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(addItem()));
     }
-    connect(_listView, TQT_SIGNAL(selectionChanged()), TQT_SLOT(selectionChanged()));
+    connect(_listView, TQ_SIGNAL(selectionChanged()), TQ_SLOT(selectionChanged()));
 
     // maybe supplied lineedit has some text already
     typedSomething(m_lineEdit ? m_lineEdit->text() : TQString());
@@ -111,7 +111,7 @@ void EditListBox::setButtons(Buttons buttons)
 #endif
         _addButton->setEnabled(false);
         _addButton->show();
-        connect(_addButton, TQT_SIGNAL(clicked()), TQT_SLOT(addItem()));
+        connect(_addButton, TQ_SIGNAL(clicked()), TQ_SLOT(addItem()));
         _buttonsLayout->addWidget(_addButton);
     }
 
@@ -121,7 +121,7 @@ void EditListBox::setButtons(Buttons buttons)
         _removeButton = new KPushButton(KGuiItem(i18n("Remove"), "clear"), this);
         _removeButton->setEnabled(false);
         _removeButton->show();
-        connect(_removeButton, TQT_SIGNAL(clicked()), TQT_SLOT(removeItem()));
+        connect(_removeButton, TQ_SIGNAL(clicked()), TQ_SLOT(removeItem()));
         _buttonsLayout->addWidget(_removeButton);
     }
 
@@ -130,7 +130,7 @@ void EditListBox::setButtons(Buttons buttons)
     if ( buttons & RemoveAll ) {
         _removeAllButton = new KPushButton(KGuiItem(i18n("Remove All"), "delete"), this);
         _removeAllButton->show();
-        connect(_removeAllButton, TQT_SIGNAL(clicked()), TQT_SLOT(clear()));
+        connect(_removeAllButton, TQ_SIGNAL(clicked()), TQ_SLOT(clear()));
         _buttonsLayout->addWidget(_removeAllButton);
     }
 
@@ -142,12 +142,12 @@ void EditListBox::setButtons(Buttons buttons)
         _moveUpButton = new KPushButton(KGuiItem(i18n("Move &Up"), "go-up"), this);
         _moveUpButton->setEnabled(false);
         _moveUpButton->show();
-        connect(_moveUpButton, TQT_SIGNAL(clicked()), TQT_SLOT(moveItemUp()));
+        connect(_moveUpButton, TQ_SIGNAL(clicked()), TQ_SLOT(moveItemUp()));
         _buttonsLayout->addWidget(_moveUpButton);
         _moveDownButton = new KPushButton(KGuiItem(i18n("Move &Down"), "go-down"), this);
         _moveDownButton->setEnabled(false);
         _moveDownButton->show();
-        connect(_moveDownButton, TQT_SIGNAL(clicked()), TQT_SLOT(moveItemDown()));
+        connect(_moveDownButton, TQ_SIGNAL(clicked()), TQ_SLOT(moveItemDown()));
         _buttonsLayout->addWidget(_moveDownButton);
     }
 
@@ -156,7 +156,7 @@ void EditListBox::setButtons(Buttons buttons)
     if ( buttons & Reset ) {
         _resetButton = new KPushButton(KStdGuiItem::reset(), this);
         _resetButton->show();
-        connect(_resetButton, TQT_SIGNAL(clicked()), TQT_SIGNAL(reset()));
+        connect(_resetButton, TQ_SIGNAL(clicked()), TQ_SIGNAL(reset()));
         _buttonsLayout->addWidget(_resetButton);
     }
 }
