@@ -32,8 +32,8 @@ GenericHexWordEditor::GenericHexWordEditor(uint nbChars, bool hasBlankValue, TQW
   : KLineEdit(parent, "hex_word_editor"), _nbChars(nbChars), _hasBlankValue(hasBlankValue)
 {
   setFocusPolicy(TQWidget::ClickFocus);
-  setValidator(new HexValueValidator(nbChars, TQT_TQOBJECT(this)));
-  connect(this, TQT_SIGNAL(textChanged(const TQString &)), TQT_SLOT(slotTextChanged()));
+  setValidator(new HexValueValidator(nbChars, this));
+  connect(this, TQ_SIGNAL(textChanged(const TQString &)), TQ_SLOT(slotTextChanged()));
   setFrame(false);
 }
 
@@ -81,10 +81,10 @@ bool GenericHexWordEditor::event(TQEvent *e)
     changeValue();
     break;
   case TQEvent::FocusIn:
-    TQTimer::singleShot(0, this, TQT_SLOT(selectAll())); // ugly but it works
+    TQTimer::singleShot(0, this, TQ_SLOT(selectAll())); // ugly but it works
     break;
   case TQEvent::KeyPress:
-    switch ( TQT_TQKEYEVENT(e)->key() ) {
+    switch ( static_cast<TQKeyEvent*>(e)->key() ) {
       case Key_Next:
         emit moveNextPage();
         return true;
