@@ -167,8 +167,8 @@ void Register::ListViewItem::editDone(int col, const TQWidget *edit)
 Register::LineEdit::LineEdit(TQWidget *parent, const char *name)
   : NumberLineEdit(parent, name), _base(NumberBase::Nb_Types)
 {
-  connect(this, TQT_SIGNAL(lostFocus()), TQT_SLOT(updateText()));
-  connect(this, TQT_SIGNAL(returnPressed()), TQT_SLOT(returnPressedSlot()));
+  connect(this, TQ_SIGNAL(lostFocus()), TQ_SLOT(updateText()));
+  connect(this, TQ_SIGNAL(returnPressed()), TQ_SLOT(returnPressedSlot()));
 }
 
 void Register::LineEdit::updateText()
