@@ -38,10 +38,10 @@ Pic::MemoryEditorLegend::Data::Data(const TQString &text, TQWidget *parent)
 {
   button = new PopupButton(text, parent);
   TDEActionCollection *ac = 0;
-  TDEAction *a = new TDEAction(i18n("Go to start"), "go-top", 0, TQT_TQOBJECT(parent), TQT_SLOT(gotoStart()), ac);
+  TDEAction *a = new TDEAction(i18n("Go to start"), "go-top", 0, parent, TQ_SLOT(gotoStart()), ac);
   actions.append(a);
   button->appendAction(a);
-  a = new TDEAction(i18n("Go to end"), "go-bottom", 0, TQT_TQOBJECT(parent), TQT_SLOT(gotoEnd()), ac);
+  a = new TDEAction(i18n("Go to end"), "go-bottom", 0, parent, TQ_SLOT(gotoEnd()), ac);
   actions.append(a);
   button->appendAction(a);
   label = new TQLabel(parent);
@@ -193,8 +193,8 @@ void Pic::MemoryRangeEditor::addLegend(TQVBoxLayout *vbox)
 {
   if ( type()==MemoryRangeType::Code || type()==MemoryRangeType::Eeprom ) {
     _legend = new MemoryEditorLegend(type(), memory(), this);
-    connect(_legend, TQT_SIGNAL(setStartWord(int)), TQT_SLOT(setStartWord(int)));
-    connect(_legend, TQT_SIGNAL(setEndWord(int)), TQT_SLOT(setEndWord(int)));
+    connect(_legend, TQ_SIGNAL(setStartWord(int)), TQ_SLOT(setStartWord(int)));
+    connect(_legend, TQ_SIGNAL(setEndWord(int)), TQ_SLOT(setEndWord(int)));
     vbox->addWidget(_legend);
   }
 }
@@ -317,7 +317,7 @@ void Pic::MemoryUserIdEditor::init(bool first)
 {
   MemoryTypeRangeEditor::init(first);
   _setToChecksum = new TDEToggleAction(i18n("Set to unprotected checksum"), 0, 0,
-    TQT_TQOBJECT(this), TQT_SLOT(toggleSetToChecksum()), Main::toplevel().actionCollection());
+    this, TQ_SLOT(toggleSetToChecksum()), Main::toplevel().actionCollection());
   addAction(_setToChecksum);
   if ( readConfigEntry(BaseGlobalConfig::UserIdSetToChecksum).toBool() && memory().isClear(MemoryRangeType::UserId) ) {
     _setToChecksum->activate();
