@@ -40,9 +40,9 @@ Breakpoint::View::View(TQWidget *parent)
 {
   TQVBoxLayout *top = new TQVBoxLayout(this);
   _listview = new ListView(this);
-  connect(_listview, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(itemClicked(TQListViewItem *)));
-  connect(_listview, TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
+  connect(_listview, TQ_SIGNAL(clicked(TQListViewItem *)), TQ_SLOT(itemClicked(TQListViewItem *)));
+  connect(_listview, TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
   _listview->setAllColumnsShowFocus(true);
   _listview->addColumn(i18n("Status"));
   _listview->addColumn(i18n("Location"));
@@ -71,13 +71,13 @@ void Breakpoint::View::itemClicked(TQListViewItem *item)
   if ( item==0 ) return;
   const Data &data = static_cast<ListViewItem *>(item)->data();
   Address address = Breakpoint::list().address(data);
-  TextEditor *editor = ::tqqt_cast<TextEditor *>(Main::currentEditor());
+  TextEditor *editor = ::tqt_cast<TextEditor *>(Main::currentEditor());
   const Coff::TextObject *coff = Debugger::manager->coff();
   int line = -1;
   if ( coff && editor && editor->fileType()==PURL::Coff && address.isValid() )
     line = coff->lineForAddress(editor->url(), address);
   if ( line==-1 ) {
-    editor = ::tqqt_cast<TextEditor *>(Main::editorManager().openEditor(data.url));
+    editor = ::tqt_cast<TextEditor *>(Main::editorManager().openEditor(data.url));
     line = data.line;
   }
   if ( editor==0 ) return;
