@@ -32,7 +32,7 @@ GeneratorDialog::GeneratorDialog(const TQString &title, TQWidget *parent, const
   TQLabel *label = new TQLabel(i18n("Device:"), mainWidget());
   hbox->addWidget(label);
   _deviceChooser = new DeviceChooser::Button(false, mainWidget());
-  connect(_deviceChooser, TQT_SIGNAL(changed()), TQT_SLOT(reset()));
+  connect(_deviceChooser, TQ_SIGNAL(changed()), TQ_SLOT(reset()));
   hbox->addWidget(_deviceChooser);
   hbox->addSpacing(20);
 
@@ -42,7 +42,7 @@ GeneratorDialog::GeneratorDialog(const TQString &title, TQWidget *parent, const
   Tool::Lister::ConstIterator it;
   for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it)
     _configType->appendItem(it.key(), it.data()->label());
-  connect(_configType->widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(typeChanged()));
+  connect(_configType->widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(typeChanged()));
   hbox->addWidget(_configType->widget());
 
   label = new TQLabel(i18n("Tool Type:"), mainWidget());
@@ -50,7 +50,7 @@ GeneratorDialog::GeneratorDialog(const TQString &title, TQWidget *parent, const
   _toolType = new KeyComboBox<PURL::ToolType>(mainWidget());
   FOR_EACH(PURL::ToolType, type) _toolType->appendItem(type, type.label());
   _toolType->fixMinimumWidth();
-  connect(_toolType->widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(compute()));
+  connect(_toolType->widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(compute()));
   hbox->addWidget(_toolType->widget());
   hbox->addStretch(1);
 
@@ -159,7 +159,7 @@ void ConfigGenerator::reset()
   _configEditor = Device::groupui(*data).createConfigEditor(*_memory, mainWidget());
   if (_configEditor) {
     _configEditor->show();
-    connect(_configEditor, TQT_SIGNAL(modified()), TQT_SLOT(compute()));
+    connect(_configEditor, TQ_SIGNAL(modified()), TQ_SLOT(compute()));
     _configEditor->updateDisplay();
     _hbox->addWidget(_configEditor);
   }
