@@ -32,7 +32,7 @@ void ConsoleView::showEvent(TQShowEvent *e)
       top->addWidget(label);
       return;
     } else {
-      TQWidget *pwidget = static_cast<KParts::Part *>(factory->create(TQT_TQOBJECT(this), "konsole"))->widget();
+      TQWidget *pwidget = static_cast<KParts::Part *>(factory->create(this, "konsole"))->widget();
       pwidget->show();
       top->addWidget(pwidget);
       setFocusProxy(pwidget);
