@@ -94,10 +94,10 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
   TQHBoxLayout *hbox = new TQHBoxLayout(top, 10);
   TQVBoxLayout *vbox = new TQVBoxLayout(hbox);
   _listTypeCombo = new EnumComboBox<ListType>("list_type", mainWidget());
-  connect(_listTypeCombo->combo(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_listTypeCombo->combo(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   vbox->addWidget(_listTypeCombo->combo());
   TQPushButton *button = new KPushButton(KGuiItem(i18n("Reset Filters"), "reload"), mainWidget());
-  connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(resetFilters()));
+  connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(resetFilters()));
   vbox->addWidget(button);
   vbox->addStretch(1);
 
@@ -122,7 +122,7 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
   Config config;
   const Programmer::Group *pgroup = config.programmerGroup();
   if (pgroup) _programmerCombo->setCurrentItem(pgroup->name());
-  connect(_programmerCombo->widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_programmerCombo->widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   shbox->addWidget(_programmerCombo->widget());
 
   // tool filter
@@ -135,12 +135,12 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
   }
   const Tool::Group *tgroup = config.toolGroup();
   if (tgroup) _toolCombo->setCurrentItem(tgroup->name());
-  connect(_toolCombo->widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_toolCombo->widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   shbox->addWidget(_toolCombo->widget());
 
   // memory filter
   _memoryCombo = new EnumComboBox<Device::MemoryTechnology>(i18n("<Memory Type>"), "memory_technology", frame);
-  connect(_memoryCombo->combo(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_memoryCombo->combo(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   shbox->addWidget(_memoryCombo->combo());
 
   shbox->addStretch(1);
@@ -148,12 +148,12 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
 
   // status filter
   _statusCombo = new EnumComboBox<Device::Status>(i18n("<Status>"), "status", frame);
-  connect(_statusCombo->combo(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_statusCombo->combo(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   shbox->addWidget(_statusCombo->combo());
 
   // features filter
   _featureCombo = new EnumComboBox<Pic::Feature>(i18n("<Feature>"), "feature", frame);
-  connect(_featureCombo->combo(), TQT_SIGNAL(activated(int)), TQT_SLOT(updateList()));
+  connect(_featureCombo->combo(), TQ_SIGNAL(activated(int)), TQ_SLOT(updateList()));
   shbox->addWidget(_featureCombo->combo());
 
   shbox->addStretch(1);
@@ -162,13 +162,13 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
   TQValueList<int> widths;
   widths += 80;
   widths += 500;
-  Splitter *splitter = new Splitter(widths,Qt::Horizontal, mainWidget(), "device_shooser_splitter");
+  Splitter *splitter = new Splitter(widths,TQt::Horizontal, mainWidget(), "device_shooser_splitter");
   top->addWidget(splitter, 1);
   _listView = new TDEListView(splitter);
-  connect(_listView, TQT_SIGNAL(currentChanged(TQListViewItem *)),
-          TQT_SLOT(currentChanged(TQListViewItem *)));
-  connect(_listView, TQT_SIGNAL(doubleClicked(TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(listDoubleClicked(TQListViewItem *)));
+  connect(_listView, TQ_SIGNAL(currentChanged(TQListViewItem *)),
+          TQ_SLOT(currentChanged(TQListViewItem *)));
+  connect(_listView, TQ_SIGNAL(doubleClicked(TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(listDoubleClicked(TQListViewItem *)));
   _listView->setAllColumnsShowFocus(true);
   _listView->setRootIsDecorated(true);
   _listView->setSorting(-1);
@@ -177,8 +177,8 @@ DeviceChooser::Dialog::Dialog(const TQString &device, Type type, TQWidget *paren
 
   // device view
   _deviceView = new View(splitter);
-  connect(_deviceView, TQT_SIGNAL(deviceChanged(const TQString &)),
-          TQT_SLOT(deviceChange(const TQString &)));
+  connect(_deviceView, TQ_SIGNAL(deviceChanged(const TQString &)),
+          TQ_SLOT(deviceChange(const TQString &)));
 
   updateList(device);
 }
@@ -343,12 +343,12 @@ DeviceChooser::Button::Button(bool withAuto, TQWidget *parent)
 {
   TQHBoxLayout *hbox = new TQHBoxLayout(this, 0, 10);
   _combo = new ComboBox(withAuto, this);
-  connect(_combo, TQT_SIGNAL(activated(int)), TQT_SIGNAL(changed()));
+  connect(_combo, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
   hbox->addWidget(_combo);
   TDEIconLoader loader;
   TQIconSet iconset = loader.loadIcon("document-open", TDEIcon::Toolbar);
   KPushButton *button = new KPushButton(iconset, TQString(), this);
-  connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(chooseDevice()));
+  connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(chooseDevice()));
   hbox->addWidget(button);
 }
 
@@ -399,8 +399,8 @@ DeviceChooser::View::View(TQWidget *parent)
   _info = new Browser(this);
   _info->setMimeSourceFactory(&_msf);
   insertTab(_info, i18n("Information"));
-  connect(_info, TQT_SIGNAL(deviceChanged(const TQString &)),
-          TQT_SIGNAL(deviceChanged(const TQString &)));
+  connect(_info, TQ_SIGNAL(deviceChanged(const TQString &)),
+          TQ_SIGNAL(deviceChanged(const TQString &)));
 
   // Memory Map
   _memory = new Browser(this);
@@ -457,7 +457,7 @@ DeviceChooser::Editor::Editor(const TQString &title, const TQString &tag, TQWidg
 TQWidget *DeviceChooser::Editor::createView(const Device::Data *, TQWidget *parent)
 {
   DeviceChooser::View *view = new DeviceChooser::View(parent);
-  connect(view, TQT_SIGNAL(deviceChanged(const TQString &)), TQT_SIGNAL(deviceChanged(const TQString &)));
+  connect(view, TQ_SIGNAL(deviceChanged(const TQString &)), TQ_SIGNAL(deviceChanged(const TQString &)));
   view->setDevice(_device, true);
   return view;
 }
