@@ -96,7 +96,7 @@ EditorManager::EditorManager(TQWidget *parent)
   : TabWidget(parent, "editor_manager"), _current(0)
 {
   setTabBar(new EditorTabBar(this));
-  connect(this, TQT_SIGNAL(currentChanged(TQWidget *)), TQT_SLOT(showEditor(TQWidget *)));
+  connect(this, TQ_SIGNAL(currentChanged(TQWidget *)), TQ_SLOT(showEditor(TQWidget *)));
   setHoverCloseButton(readConfigEntry(BaseGlobalConfig::ShowTabCloseButton).toBool());
   setHoverCloseButtonDelayed(false);
 }
@@ -127,10 +127,10 @@ void EditorManager::connectEditor(Editor *editor)
     disconnectEditor(currentEditor());
     if ( editor==0 ) return;
     editor->addGui();
-    connect(editor, TQT_SIGNAL(modified()), TQT_SLOT(modifiedSlot()));
-    connect(editor, TQT_SIGNAL(guiChanged()), TQT_SIGNAL(guiChanged()));
-    connect(editor, TQT_SIGNAL(dropEventPass(TQDropEvent *)), TQT_SLOT(slotDropEvent(TQDropEvent *)));
-    connect(editor, TQT_SIGNAL(statusTextChanged(const TQString &)), TQT_SIGNAL(statusChanged(const TQString &)));
+    connect(editor, TQ_SIGNAL(modified()), TQ_SLOT(modifiedSlot()));
+    connect(editor, TQ_SIGNAL(guiChanged()), TQ_SIGNAL(guiChanged()));
+    connect(editor, TQ_SIGNAL(dropEventPass(TQDropEvent *)), TQ_SLOT(slotDropEvent(TQDropEvent *)));
+    connect(editor, TQ_SIGNAL(statusTextChanged(const TQString &)), TQ_SIGNAL(statusChanged(const TQString &)));
 }
 
 void EditorManager::modifiedSlot()
@@ -161,7 +161,7 @@ void EditorManager::updateTitles()
     static_cast<EditorTabBar *>(tabBar())->setReadOnly(indexOf(*it), (*it)->isReadOnly());
     TQPixmap pixmap;
     if ( (*it)->isModified() ) pixmap = modified;
-    else if ( ::tqqt_cast< ::DeviceEditor *>(*it)==0 ) pixmap = PURL::icon((*it)->fileType());
+    else if ( ::tqt_cast< ::DeviceEditor *>(*it)==0 ) pixmap = PURL::icon((*it)->fileType());
     else pixmap = chip;
     changeTab(*it, pixmap.isNull() ? def : pixmap, title(**it));
   }
