@@ -30,13 +30,13 @@
 
 //-----------------------------------------------------------------------------
 HexEditorPart::HexEditorPart(HexEditor *editor)
- : KParts::ReadWritePart(TQT_TQOBJECT(editor), "hex_editor_part")
+ : KParts::ReadWritePart(editor, "hex_editor_part")
 {
   setXMLFile("hexeditorpartui.rc");
 
-  (void)KStdAction::save(TQT_TQOBJECT(editor), TQT_SLOT(save()), actionCollection());
-  (void)KStdAction::saveAs(TQT_TQOBJECT(editor), TQT_SLOT(saveAs()), actionCollection());
-  (void)new TDEToggleAction(i18n("Read Only Mode"), 0, 0, TQT_TQOBJECT(editor), TQT_SLOT(toggleReadOnly()), actionCollection(), "tools_toggle_write_lock");
+  (void)KStdAction::save(editor, TQ_SLOT(save()), actionCollection());
+  (void)KStdAction::saveAs(editor, TQ_SLOT(saveAs()), actionCollection());
+  (void)new TDEToggleAction(i18n("Read Only Mode"), 0, 0, editor, TQ_SLOT(toggleReadOnly()), actionCollection(), "tools_toggle_write_lock");
 }
 
 void HexEditorPart::setReadWrite(bool rw)
@@ -85,9 +85,9 @@ TQWidget *HexEditor::createView(const Device::Data *data, TQWidget *parent)
   }
   if ( data==0 ) return new TQWidget(parent);
   Device::HexView *hv = Device::groupui(*data).createHexView(*this, parent);
-  connect(hv, TQT_SIGNAL(modified()), TQT_SLOT(slotModified()));
+  connect(hv, TQ_SIGNAL(modified()), TQ_SLOT(slotModified()));
   _dirty = true;
-  TQTimer::singleShot(0, this, TQT_SLOT(simpleLoad()));
+  TQTimer::singleShot(0, this, TQ_SLOT(simpleLoad()));
   return hv;
 }
 
