@@ -66,21 +66,21 @@ LikeBack::LikeBack(Button buttons)
         m_likeButton->setIconSet(likeIconSet);
         m_likeButton->setTextLabel(i18n("I Like..."));
         m_likeButton->setAutoRaise(true);
-        connect( m_likeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(iLike()) );
+        connect( m_likeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(iLike()) );
         layout->add(m_likeButton);
 
         TQToolButton *m_dislikeButton = new TQToolButton(this, "idonotlike");
         m_dislikeButton->setIconSet(dislikeIconSet);
         m_dislikeButton->setTextLabel(i18n("I Do not Like..."));
         m_dislikeButton->setAutoRaise(true);
-        connect( m_dislikeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(iDoNotLike()) );
+        connect( m_dislikeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(iDoNotLike()) );
         layout->add(m_dislikeButton);
 
         TQToolButton *m_bugButton = new TQToolButton(this, "ifoundabug");
         m_bugButton->setIconSet(bugIconSet);
         m_bugButton->setTextLabel(i18n("I Found a Bug..."));
         m_bugButton->setAutoRaise(true);
-        connect( m_bugButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(iFoundABug()) );
+        connect( m_bugButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(iFoundABug()) );
         layout->add(m_bugButton);
 
         m_configureButton = new TQToolButton(this, "configure");
@@ -88,17 +88,17 @@ LikeBack::LikeBack(Button buttons)
         m_configureButton->setIconSet(helpIconSet);
         m_configureButton->setTextLabel(i18n("Configure..."));
         m_configureButton->setAutoRaise(true);
-        connect( m_likeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(configure()) );
+        connect( m_likeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(configure()) );
         layout->add(m_configureButton);
 
         TQPopupMenu *configureMenu = new TQPopupMenu(this);
-        configureMenu->insertItem(helpIconSet, i18n("What's &This?"), this , TQT_SLOT(showWhatsThisMessage()) );
+        configureMenu->insertItem(helpIconSet, i18n("What's &This?"), this , TQ_SLOT(showWhatsThisMessage()) );
         TQIconSet changeEmailIconSet = kapp->iconLoader()->loadIconSet("mail_generic", TDEIcon::Small);
-        configureMenu->insertItem(changeEmailIconSet, i18n("&Configure Email Address..."), this , TQT_SLOT(askEMail()) );
+        configureMenu->insertItem(changeEmailIconSet, i18n("&Configure Email Address..."), this , TQ_SLOT(askEMail()) );
 //        TQIconSet dontHelpIconSet = kapp->iconLoader()->loadIconSet("process-stop", TDEIcon::Small);
-//        configureMenu->insertItem( dontHelpIconSet, i18n("&Do not Help Anymore"), this , TQT_SLOT(doNotHelpAnymore()) );
+//        configureMenu->insertItem( dontHelpIconSet, i18n("&Do not Help Anymore"), this , TQ_SLOT(doNotHelpAnymore()) );
         m_configureButton->setPopup(configureMenu);
-        connect( m_configureButton, TQT_SIGNAL(pressed()), this, TQT_SLOT(openConfigurePopup()) );
+        connect( m_configureButton, TQ_SIGNAL(pressed()), this, TQ_SLOT(openConfigurePopup()) );
 
         if (!emailAddressAlreadyProvided())
                 //beginFetchingEmail(); // Begin before showing the message, so we have time!
@@ -112,7 +112,7 @@ LikeBack::LikeBack(Button buttons)
 
         resize(sizeHint());
 
-        connect( &m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(autoMove()) );
+        connect( &m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(autoMove()) );
         m_timer.start(10);
 
         s_instance = this;
@@ -131,7 +131,7 @@ void LikeBack::doNotHelpAnymore()
 {
         disable();
         int result = KMessageBox::questionYesNo(
-                        TQT_TQWIDGET(kapp->activeWindow()),
+                        kapp->activeWindow(),
                         i18n("Are you sure you do not want to participate anymore in the application enhancing program?"),
                         i18n("Do not Help Anymore"));
         if (result == KMessageBox::No) {
@@ -276,7 +276,7 @@ void LikeBack::autoMove()
 {
         static TQWidget *lastWindow = 0;
 
-        TQWidget *window = TQT_TQWIDGET(kapp->activeWindow());
+        TQWidget *window = kapp->activeWindow();
         // When a Kicker applet has the focus, like the Commandline TQLineEdit,
         // the systemtray icon indicates to be the current window and the LikeBack is shown next to the system tray icon.
         // It's obviously bad ;-) :
@@ -322,7 +322,7 @@ void LikeBack::configure()
 TQString LikeBack::activeWindowPath()
 {
         TQStringList windowNames;
-        TQWidget *window = TQT_TQWIDGET(kapp->activeWindow());
+        TQWidget *window = kapp->activeWindow();
         while (window) {
                 TQString name = window->name();
                 if (name == "unnamed")
@@ -386,7 +386,7 @@ void LikeBack::askEMail()
         //TQString namedMailExpString = "[.]*[ \\t]+<" + mailExpString + ">";
         //TQRegExp mailExp("^(|" + mailExpString + "|" + namedMailExpString + ")$");
         TQRegExp mailExp("^(|" + mailExpString + ")$");
-        TQRegExpValidator emailValidator(mailExp, TQT_TQOBJECT(this));
+        TQRegExpValidator emailValidator(mailExp, this);
 
         disable();
         TQString email = KInputDialog::getText(
@@ -396,7 +396,7 @@ void LikeBack::askEMail()
                         "<p>" + i18n("The email address is optional. If you do not provide any, your comments will be sent anonymously. Just click OK in that case.") + "</p>" +
                         "<p>" + i18n("You can change or remove your email address whenever you want. For that, use the little arrow icon at the top-right corner of a window.") + "</p>" +
                         "<p>" + i18n("Your email address (keep empty to post comments anonymously):"),
-                        currentEMailAddress, &ok, TQT_TQWIDGET(kapp->activeWindow()), /*name=*/(const char*)0, &emailValidator);
+                        currentEMailAddress, &ok, kapp->activeWindow(), /*name=*/(const char*)0, &emailValidator);
         enable();
 
         if (ok)
@@ -453,7 +453,7 @@ void LikeBack::init(bool isDevelopmentVersion, Button buttons)
                 return;
         m_process = new TDEProcess();
         *m_process << TQString::fromLatin1("tdecmshell") << TQString::fromLatin1("kcm_useraccount");
-        connect( m_process, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SLOT(endFetchingEmailFrom()) );
+        connect( m_process, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(endFetchingEmailFrom()) );
         if (!m_process->start()) {
                 kdDebug() << "Couldn't start tdecmshell.." << endl;
                 delete m_process;
@@ -503,7 +503,7 @@ void LikeBack::endFetchingEmailFrom()
 /** class LikeBackDialog: */
 
 LikeBackDialog::LikeBackDialog(LikeBack::Button reason, TQString windowName, TQString context)
- : KDialog(TQT_TQWIDGET(kapp->activeWindow()), "_likeback_feedback_window_")
+ : KDialog(kapp->activeWindow(), "_likeback_feedback_window_")
  , m_reason(reason)
  , m_windowName(windowName)
  , m_context(context)
@@ -582,8 +582,8 @@ LikeBackDialog::LikeBackDialog(LikeBack::Button reason, TQString windowName, TQS
         m_sendButton = new TQPushButton(sendIconSet, i18n("Send"), coloredWidget);
         m_sendButton->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Expanding);
         m_sendButton->setEnabled(false);
-        connect( m_sendButton, TQT_SIGNAL(clicked()),     this, TQT_SLOT(send())           );
-        connect( m_comment,    TQT_SIGNAL(textChanged()), this, TQT_SLOT(commentChanged()) );
+        connect( m_sendButton, TQ_SIGNAL(clicked()),     this, TQ_SLOT(send())           );
+        connect( m_comment,    TQ_SIGNAL(textChanged()), this, TQ_SLOT(commentChanged()) );
         commentLayout->addWidget(m_comment);
         commentLayout->addWidget(m_sendButton);
         coloredWidgetLayout->addLayout(commentLayout);
@@ -635,7 +635,7 @@ void LikeBackDialog::send()
 
 //        std::cout << "http://" << LikeBack::hostName() << ":" << LikeBack::hostPort() << LikeBack::remotePath() << std::endl;
 //        std::cout << data << std::endl;
-        connect( http, TQT_SIGNAL(requestFinished(int, bool)), this, TQT_SLOT(requestFinished(int, bool)) );
+        connect( http, TQ_SIGNAL(requestFinished(int, bool)), this, TQ_SLOT(requestFinished(int, bool)) );
 //      http->post(LikeBack::remotePath(), data.utf8());
 
         TQHttpRequestHeader header("POST", LikeBack::remotePath());
