@@ -77,18 +77,18 @@ TQPopupMenu *Log::Widget::createPopupMenu(const TQPoint &pos)
   _popup = TQTextEdit::createPopupMenu(pos);
   TDEIconLoader loader;
   TQIconSet iset = loader.loadIconSet("document-save", TDEIcon::Small, 0);
-  _popup->insertItem(iset, "Save As...", this, TQT_SLOT(saveAs()));
+  _popup->insertItem(iset, "Save As...", this, TQ_SLOT(saveAs()));
   iset = loader.loadIconSet("window-close", TDEIcon::Small, 0);
-  _popup->insertItem(iset, "Clear", this, TQT_SLOT(clear()));
+  _popup->insertItem(iset, "Clear", this, TQ_SLOT(clear()));
   _popup->insertSeparator();
   FOR_EACH(DebugLevel, level) {
     _id[level.type()] = _popup->insertItem(level.label());
     _popup->setItemChecked(_id[level.type()], _debugLevel==level);
   }
   _popup->insertSeparator();
-  int id = _popup->insertItem(i18n("Output in console"), this, TQT_SLOT(toggleConsoleOutput()));
+  int id = _popup->insertItem(i18n("Output in console"), this, TQ_SLOT(toggleConsoleOutput()));
   _popup->setItemChecked(id, GlobalConfig::logOutputType()==GuiConsole);
-  connect(_popup, TQT_SIGNAL(activated(int)), TQT_SLOT(toggleVisible(int)));
+  connect(_popup, TQ_SIGNAL(activated(int)), TQ_SLOT(toggleVisible(int)));
   return _popup;
 }
 
