@@ -26,18 +26,18 @@ NewDialog::NewDialog(const TQString &caption, TQWidget *parent)
   _fLabel = new TQLabel(mainWidget());
   _top->addWidget(_fLabel, 0, 0);
   _filename = new TQLineEdit(mainWidget());
-  connect(_filename, TQT_SIGNAL(textChanged(const TQString &)), TQT_SLOT(changed()));
+  connect(_filename, TQ_SIGNAL(textChanged(const TQString &)), TQ_SLOT(changed()));
   _top->addMultiCellWidget(_filename, 0,0, 1,3);
 
   TQLabel *label= new TQLabel(i18n("Location:"), mainWidget());
   _top->addWidget(label, 1, 0);
   _dir = new TQLineEdit(mainWidget());
-  connect(_dir, TQT_SIGNAL(textChanged(const TQString &)), TQT_SLOT(changed()));
+  connect(_dir, TQ_SIGNAL(textChanged(const TQString &)), TQ_SLOT(changed()));
   _top->addMultiCellWidget(_dir, 1,1, 1,2);
   TDEIconLoader loader;
   TQIconSet iconset = loader.loadIcon("document-open", TDEIcon::Toolbar);
   KPushButton *button = new KPushButton(iconset, TQString(), mainWidget());
-  connect(button, TQT_SIGNAL(clicked()), TQT_SLOT(browse()));
+  connect(button, TQ_SIGNAL(clicked()), TQ_SLOT(browse()));
   _top->addWidget(button, 1, 3);
 
   _filename->setFocus();
