@@ -38,13 +38,13 @@
 ProjectManager::View::View(TQWidget *parent)
   : ListView(parent, "project_manager"), _project(0), _modified(false)
 {
-  connect(TQT_TQOBJECT(this), TQT_SIGNAL(mouseButtonClicked(int, TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(clicked(int, TQListViewItem *, const TQPoint &, int)));
-  connect(TQT_TQOBJECT(this), TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
-  connect(TQT_TQOBJECT(this), TQT_SIGNAL(itemRenamed(TQListViewItem *, int, const TQString &)),
-          TQT_SLOT(renamed(TQListViewItem *, int, const TQString &)));
-  connect(TQT_TQOBJECT(this), TQT_SIGNAL(moved()), TQT_SLOT(filesReordered()));
+  connect(this, TQ_SIGNAL(mouseButtonClicked(int, TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(clicked(int, TQListViewItem *, const TQPoint &, int)));
+  connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
+  connect(this, TQ_SIGNAL(itemRenamed(TQListViewItem *, int, const TQString &)),
+          TQ_SLOT(renamed(TQListViewItem *, int, const TQString &)));
+  connect(this, TQ_SIGNAL(moved()), TQ_SLOT(filesReordered()));
 
   header()->hide();
   setSorting(-1);
@@ -54,7 +54,7 @@ ProjectManager::View::View(TQWidget *parent)
   setAcceptDrops(true);
   setDragEnabled(true);
   setDropVisualizer(true);
-  TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(init()));;
+  TQTimer::singleShot(0, this, TQ_SLOT(init()));;
 }
 
 ProjectManager::View::~View()
@@ -178,8 +178,8 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
     RootItem *ri = static_cast<RootItem *>(item);
     if ( _project==0 ) {
       if ( ri->url().isEmpty() ) {
-        pop.insertItem("piklab_createproject", i18n("New Project..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newProject()));
-        pop.insertItem("piklab_openproject", i18n("Open Project..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(openProject()));
+        pop.insertItem("piklab_createproject", i18n("New Project..."), &Main::toplevel(), TQ_SLOT(newProject()));
+        pop.insertItem("piklab_openproject", i18n("Open Project..."), &Main::toplevel(), TQ_SLOT(openProject()));
         pop.exec(p);
       } else {
         pop.insertTitle(i18n("Standalone File"));
@@ -188,16 +188,16 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
       }
     } else {
       pop.insertTitle(i18n("Project"));
-      pop.insertItem("configure", i18n("Options..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(configureProject()));
-      pop.insertItem("edit-find", i18n("Find Files..."),   TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(runKfind()));
+      pop.insertItem("configure", i18n("Options..."), &Main::toplevel(), TQ_SLOT(configureProject()));
+      pop.insertItem("edit-find", i18n("Find Files..."),   &Main::toplevel(), TQ_SLOT(runKfind()));
       pop.insertSeparator();
-      pop.insertItem("piklab_compile", i18n("Build Project"), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(buildProject()));
-      pop.insertItem("trashcan_empty", i18n("Clean Project"), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(cleanBuild()));
+      pop.insertItem("piklab_compile", i18n("Build Project"), &Main::toplevel(), TQ_SLOT(buildProject()));
+      pop.insertItem("trashcan_empty", i18n("Clean Project"), &Main::toplevel(), TQ_SLOT(cleanBuild()));
       pop.insertSeparator();
-      pop.insertItem("document-new", i18n("New Source File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
-      pop.insertItem("piklab_addfile", i18n("Add Source Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertSourceFiles()));
-      pop.insertItem("piklab_addfile", i18n("Add Object Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertObjectFiles()));
-      if ( Main::currentEditor() ) pop.insertItem("piklab_addcurrentfile", i18n("Add Current File"), TQT_TQOBJECT(this), TQT_SLOT(insertCurrentFile()));
+      pop.insertItem("document-new", i18n("New Source File..."), &Main::toplevel(), TQ_SLOT(newSourceFile()));
+      pop.insertItem("piklab_addfile", i18n("Add Source Files..."), this, TQ_SLOT(insertSourceFiles()));
+      pop.insertItem("piklab_addfile", i18n("Add Object Files..."), this, TQ_SLOT(insertObjectFiles()));
+      if ( Main::currentEditor() ) pop.insertItem("piklab_addcurrentfile", i18n("Add Current File"), this, TQ_SLOT(insertCurrentFile()));
       pop.exec(p);
     }
   } else if ( item->rtti()==FileRtti ) {
@@ -211,15 +211,15 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
     if ( _project==0 ) return;
     if ( group==LinkerObjectGroup ) {
       pop.insertTitle(i18n("Objects"));
-      pop.insertItem("piklab_addfile", i18n("Add Object Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertObjectFiles()));
+      pop.insertItem("piklab_addfile", i18n("Add Object Files..."), this, TQ_SLOT(insertObjectFiles()));
       pop.exec(p);
     } else if ( group==SourceGroup || group==HeaderGroup ) {
       pop.insertTitle(i18n("Sources"));
-      pop.insertItem("document-new", i18n("New File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
-      pop.insertItem("piklab_addfile", i18n("Add Source Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertSourceFiles()));
+      pop.insertItem("document-new", i18n("New File..."), &Main::toplevel(), TQ_SLOT(newSourceFile()));
+      pop.insertItem("piklab_addfile", i18n("Add Source Files..."), this, TQ_SLOT(insertSourceFiles()));
       pop.exec(p);
     } else if ( group==DeviceGroup ) {
-      pop.insertItem("document-new", i18n("Select Device..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(showDeviceInfo()));
+      pop.insertItem("document-new", i18n("Select Device..."), &Main::toplevel(), TQ_SLOT(showDeviceInfo()));
       pop.exec(p);
     }
   }
@@ -413,7 +413,7 @@ void ProjectManager::View::removeFile(const PURL::Url &url)
 void ProjectManager::View::clicked(int button, TQListViewItem *item, const TQPoint &, int)
 {
   if ( item==0 ) return;
-  if ( button!=Qt::LeftButton ) return;
+  if ( button!=TQt::LeftButton ) return;
   const Device::Data *data = Main::deviceData();
   Rtti rtti = Rtti(item->rtti());
   if ( data==0 && rtti!=DeviceRtti && rtti!=RootRtti ) {
@@ -458,7 +458,7 @@ void ProjectManager::View::clicked(int button, TQListViewItem *item, const TQPoi
         if ( fi->ftype()==PURL::Coff && _project==0 && !fi->url().exists() ) {
           PURL::Url url = findFileItem(PURL::Hex)->url();
           if ( url.isEmpty() ) {
-            HexEditor *he = ::tqqt_cast<HexEditor *>(Main::currentEditor());
+            HexEditor *he = ::tqt_cast<HexEditor *>(Main::currentEditor());
             if ( he==0 ) break;
             e = new DisassemblyEditor(*he, *data, this);
           } else e = new DisassemblyEditor(url, *data, this);
