@@ -47,7 +47,7 @@ TextEditor::TextEditor(bool withDebugger, TQWidget *parent, const char *name)
 {
   KLibFactory *factory = KLibLoader::self()->factory("libkatepart");
   if ( factory==0 ) tqFatal("Could not find katepart");
-  _document = static_cast<Kate::Document *>(factory->create(TQT_TQOBJECT(this), "kate", "KTextEditor::Document"));
+  _document = static_cast<Kate::Document *>(factory->create(this, "kate", "KTextEditor::Document"));
   _oldModified = _document->isModified();
   _oldReadOnly = !_document->isReadWrite();
 
@@ -56,14 +56,14 @@ TextEditor::TextEditor(bool withDebugger, TQWidget *parent, const char *name)
   _split->setFrameStyle(TQFrame::TabWidgetPanel |  TQFrame::Sunken);
   top->addWidget(_split);
 
-  connect(_document, TQT_SIGNAL(hlChanged()), TQT_SLOT(highlightChanged()));
+  connect(_document, TQ_SIGNAL(hlChanged()), TQ_SLOT(highlightChanged()));
   setAcceptDrops(true);
   addView();
 
   for (uint i=0; i<Breakpoint::Nb_MarkTypes; i++)
     _document->setPixmap(KTextEditor::MarkInterface::MarkTypes(MARK_TYPE_DATA[i].type), pixmap(Breakpoint::MarkType(i)));
 
-  if (withDebugger) TQTimer::singleShot(0, this, TQT_SLOT(addToDebugManager()));
+  if (withDebugger) TQTimer::singleShot(0, this, TQ_SLOT(addToDebugManager()));
 }
 
 bool TextEditor::open(const PURL::Url &url)
@@ -83,7 +83,7 @@ void TextEditor::addToDebugManager()
 bool TextEditor::eventFilter(TQObject *, TQEvent *e)
 {
   if ( e->type()==TQEvent::KeyPress ) {
-    if ( TQT_TQKEYEVENT(e)->key()==Key_Escape ) return true;
+    if ( static_cast<TQKeyEvent*>(e)->key()==Key_Escape ) return true;
   }
   return false;
 }
@@ -93,10 +93,10 @@ void TextEditor::addView()
     KTextEditor::View *v = _document->createView(_split);
     if ( _view==0 ) _view = static_cast<Kate::View *>(v);
     Q_ASSERT(v);
-    connect(v, TQT_SIGNAL(gotFocus(Kate::View *)), TQT_SLOT(gotFocus(Kate::View *)));
-    connect(v, TQT_SIGNAL(cursorPositionChanged()), TQT_SLOT(statusChanged()));
-    connect(v, TQT_SIGNAL(dropEventPass(TQDropEvent *)), TQT_SIGNAL(dropEventPass(TQDropEvent *)));
-    connect(v, TQT_SIGNAL(newStatus()), TQT_SLOT(statusChanged()));
+    connect(v, TQ_SIGNAL(gotFocus(Kate::View *)), TQ_SLOT(gotFocus(Kate::View *)));
+    connect(v, TQ_SIGNAL(cursorPositionChanged()), TQ_SLOT(statusChanged()));
+    connect(v, TQ_SIGNAL(dropEventPass(TQDropEvent *)), TQ_SIGNAL(dropEventPass(TQDropEvent *)));
+    connect(v, TQ_SIGNAL(newStatus()), TQ_SLOT(statusChanged()));
     v->show();
     v->setFocus();
     v->child(0, "KateViewInternal")->installEventFilter(this);
