@@ -18,8 +18,8 @@
 ProgrammerStatusWidget::ProgrammerStatusWidget(TQWidget *parent)
   : TQObject(parent), KeyPopupButton<TQString>(parent)
 {
-  connect(widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(activatedSlot(int)));
-  widget()->appendAction(i18n("Configure..."), "configure", this, TQT_SIGNAL(configure()));
+  connect(widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(activatedSlot(int)));
+  widget()->appendAction(i18n("Configure..."), "configure", this, TQ_SIGNAL(configure()));
   widget()->appendSeparator();
   Programmer::Lister::ConstIterator it;
   for (it=Programmer::lister().begin(); it!=Programmer::lister().end(); ++it)
@@ -35,9 +35,9 @@ void ProgrammerStatusWidget::activatedSlot(int id)
 ToolStatusWidget::ToolStatusWidget(TQWidget *parent)
   : TQObject(parent), KeyPopupButton<TQString>(parent)
 {
-  connect(widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(activatedSlot(int)));
-  widget()->appendAction(i18n("Configure Toolchain..."), "configure", this, TQT_SIGNAL(configureToolchain()));
-  widget()->appendAction(i18n("Configure Compilation..."), "configure", this, TQT_SIGNAL(configure()));
+  connect(widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(activatedSlot(int)));
+  widget()->appendAction(i18n("Configure Toolchain..."), "configure", this, TQ_SIGNAL(configureToolchain()));
+  widget()->appendAction(i18n("Configure Compilation..."), "configure", this, TQ_SIGNAL(configure()));
   widget()->appendSeparator();
   Tool::Lister::ConstIterator it;
   for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it)
