@@ -29,10 +29,10 @@ Register::BaseListView::BaseListView(TQWidget *parent)
   setFullWidth(true);
   setRootIsDecorated(false);
   setAllColumnsShowFocus(true);
-  connect(this, TQT_SIGNAL(mouseButtonClicked(int, TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(itemClicked(int, TQListViewItem *, const TQPoint &, int)));
-  connect(this, TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-          TQT_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
+  connect(this, TQ_SIGNAL(mouseButtonClicked(int, TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(itemClicked(int, TQListViewItem *, const TQPoint &, int)));
+  connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+          TQ_SLOT(contextMenu(TQListViewItem *, const TQPoint &, int)));
 }
 
 //-----------------------------------------------------------------------------
@@ -66,7 +66,7 @@ void Register::RegisterListView::updateView()
 
 void Register::RegisterListView::itemClicked(int button, TQListViewItem *item, const TQPoint &, int)
 {
-  if ( item==0 || button!=Qt::LeftButton ) return;
+  if ( item==0 || button!=TQt::LeftButton ) return;
   if ( item==firstChild() ) Main::editorManager().openEditor(EditorManager::RegisterEditor);
   int id = _root->id(item);
   if ( id==-1 || _ids[id].type()==Invalid ) return;
@@ -113,7 +113,7 @@ void Register::WatchedListView::init(const Device::Data *data)
   _formatPopup = appendFormatMenu(_popup, _ids.count());
   TDEIconLoader loader;
   TQPixmap icon = loader.loadIcon("cancel", TDEIcon::Small);
-  _popup->insertItem(icon, i18n("Clear"), Debugger::manager, TQT_SLOT(stopWatchAll()));
+  _popup->insertItem(icon, i18n("Clear"), Debugger::manager, TQ_SLOT(stopWatchAll()));
 }
 
 void Register::WatchedListView::updateView()
@@ -152,7 +152,7 @@ TQString Register::WatchedListView::tooltip(const TQListViewItem &item, int col)
 
 void Register::WatchedListView::itemClicked(int button, TQListViewItem *item, const TQPoint &, int col)
 {
-  if ( item==0 || button!=Qt::LeftButton ) return;
+  if ( item==0 || button!=TQt::LeftButton ) return;
   else if ( item->rtti()==RegisterRtti ) {
     if ( col==2 && Main::programmerState()==Programmer::Halted ) static_cast<ListViewItem *>(item)->startRename();
     else item->setOpen(!item->isOpen());
@@ -202,7 +202,7 @@ Register::WatchView::WatchView(TQWidget *parent)
   TQVBoxLayout *top = new TQVBoxLayout(this);
   TQValueList<int> sizes;
   sizes.append(50);
-  Splitter *splitter = new Splitter(sizes, Qt::Vertical, this, "watch_window_splitter");
+  Splitter *splitter = new Splitter(sizes, TQt::Vertical, this, "watch_window_splitter");
   top->addWidget(splitter);
 
   _registerListView = new RegisterListView(splitter);
