@@ -17,7 +17,7 @@ namespace GPSim
 //----------------------------------------------------------------------------
 class ConfigWidget : public ::Programmer::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(const ::Programmer::Group &group, TQWidget *parent);
