@@ -40,7 +40,7 @@ Programmer::SelectConfigWidget::SelectConfigWidget()
   TQLabel *label = new TQLabel(i18n("Programmer in use:"), this);
   addWidget(label, row,row, 0,0);
   _combo = new KeyComboBox<TQString>(this);
-  connect(_combo->widget(), TQT_SIGNAL(activated(int)), TQT_SLOT(programmerChanged()));
+  connect(_combo->widget(), TQ_SIGNAL(activated(int)), TQ_SLOT(programmerChanged()));
   addWidget(_combo->widget(), row,row, 1,1);
   row++;
 
@@ -53,7 +53,7 @@ Programmer::SelectConfigWidget::SelectConfigWidget()
   _portSelectorContainer = new Container;
   _portSelectorContainer->setMargin(10);
   _portSelector = new PortSelector(_portSelectorContainer);
-  connect(_portSelector, TQT_SIGNAL(changed()), TQT_SLOT(portChanged()));
+  connect(_portSelector, TQ_SIGNAL(changed()), TQ_SLOT(portChanged()));
   _portSelectorContainer->addWidget(_portSelector, 0,0, 0,0);
 
   // specific programmer config
@@ -73,7 +73,7 @@ Programmer::SelectConfigWidget::SelectConfigWidget()
   // init
   _combo->setCurrentItem(GlobalConfig::programmerGroup().name());
   _stack->setCurrentItem(GlobalConfig::programmerGroup().name());
-  TQTimer::singleShot(0, this, TQT_SLOT(programmerChanged()));
+  TQTimer::singleShot(0, this, TQ_SLOT(programmerChanged()));
 }
 
 void Programmer::SelectConfigWidget::portChanged()
@@ -118,5 +118,5 @@ void Programmer::SelectConfigWidget::programmerChanged()
   } else if (hasTab) _tabWidget->removePage(_portSelectorContainer);
   _portSelector->setGroup(group);
   _stack->setCurrentItem(key);
-  if (isHardware) TQTimer::singleShot(0, this, TQT_SLOT(portChanged()));
+  if (isHardware) TQTimer::singleShot(0, this, TQ_SLOT(portChanged()));
 }
