@@ -31,9 +31,9 @@ Programmer::StandaloneMemoryCalibrationEditor::StandaloneMemoryCalibrationEditor
 void Programmer::StandaloneMemoryCalibrationEditor::init(bool first)
 {
   Pic::MemoryCalibrationEditor::init(first);
-  TDEAction *action = new TDEAction(i18n("Read"), "reload", 0, TQT_TQOBJECT(this), TQT_SIGNAL(updateCalibration()), Main::toplevel().actionCollection());
+  TDEAction *action = new TDEAction(i18n("Read"), "reload", 0, this, TQ_SIGNAL(updateCalibration()), Main::toplevel().actionCollection());
   addAction(action);
-  action = new TDEAction(i18n("Regenerating..."), 0, 0, TQT_TQOBJECT(this), TQT_SIGNAL(regenerate()), Main::toplevel().actionCollection());
+  action = new TDEAction(i18n("Regenerating..."), 0, 0, this, TQ_SIGNAL(regenerate()), Main::toplevel().actionCollection());
   addAction(action);
 }
 
@@ -61,10 +61,10 @@ Programmer::AdvancedDialog::AdvancedDialog(Base &base, TQWidget *parent, const c
   Properties properties = _base.group().properties();
   uint row = _programmerContainer->numRows();
   if ( properties & HasFirmware ) {
-    _firmwareContainer = new ButtonContainer(i18n("Firmware"), TQT_TQOBJECT(this), TQT_SLOT(updateFirmware()), _programmerContainer);
+    _firmwareContainer = new ButtonContainer(i18n("Firmware"), this, TQ_SLOT(updateFirmware()), _programmerContainer);
     _programmerContainer->addWidget(_firmwareContainer, row,row, 0,1);
     if ( _base.group().properties() & CanUploadFirmware )
-      _firmwareContainer->button().appendAction(i18n("Uploading..."), "piklab_burnchip", TQT_TQOBJECT(this), TQT_SLOT(uploadFirmware()));
+      _firmwareContainer->button().appendAction(i18n("Uploading..."), "piklab_burnchip", this, TQ_SLOT(uploadFirmware()));
     TQLabel *label = new TQLabel(i18n("Version:"), _firmwareContainer);
     _firmwareContainer->addWidget(label, 1,1, 0,0);
     _firmwareLabel = new TQLabel(_firmwareContainer);
@@ -76,13 +76,13 @@ Programmer::AdvancedDialog::AdvancedDialog(Base &base, TQWidget *parent, const c
   }
 
   if ( _base.group().canReadVoltages() ) {
-    _voltagesContainer = new ButtonContainer(i18n("Voltages"), TQT_TQOBJECT(this), TQT_SLOT(updateVoltages()), _programmerContainer);
+    _voltagesContainer = new ButtonContainer(i18n("Voltages"), this, TQ_SLOT(updateVoltages()), _programmerContainer);
     _programmerContainer->addWidget(_voltagesContainer, row,row, 0,1);
     row++;
   } else _voltagesContainer = 0;
 
   if ( properties & HasSelfTest ) {
-    _selfTestContainer = new ButtonContainer(i18n("Self-test"), TQT_TQOBJECT(this), TQT_SLOT(updateSelfTest()), _programmerContainer);
+    _selfTestContainer = new ButtonContainer(i18n("Self-test"), this, TQ_SLOT(updateSelfTest()), _programmerContainer);
     _programmerContainer->addWidget(_selfTestContainer, row,row, 0,1);
     row++;
   } else _selfTestContainer = 0;
@@ -102,8 +102,8 @@ Programmer::AdvancedDialog::AdvancedDialog(Base &base, TQWidget *parent, const c
   else {
     const ::Programmer::PicBase &pbase = static_cast<const ::Programmer::PicBase &>(_base);
     _calEditor = new StandaloneMemoryCalibrationEditor(pbase.deviceMemory(), _calibrationContainer);
-    connect(_calEditor, TQT_SIGNAL(updateCalibration()), TQT_SLOT(updateCalibration()));
-    connect(_calEditor, TQT_SIGNAL(regenerate()), TQT_SLOT(regenerateCalibration()));
+    connect(_calEditor, TQ_SIGNAL(updateCalibration()), TQ_SLOT(updateCalibration()));
+    connect(_calEditor, TQ_SIGNAL(regenerate()), TQ_SLOT(regenerateCalibration()));
     _calEditor->init(true);
     _calEditor->setReadOnly(true);
     _calibrationContainer->addWidget(_calEditor, 0,0, 0,0);
