@@ -38,7 +38,7 @@ ToolConfigWidget::ToolConfigWidget(Project *project)
   _argumentsType = new KComboBox(container);
   for (uint i=0; i<Nb_ArgumentsTypes; i++)
     _argumentsType->insertItem(i18n(ARGUMENTS_TYPE_LABELS[i]), i);
-  connect(_argumentsType, TQT_SIGNAL(activated(int)), TQT_SLOT(updateArguments()));
+  connect(_argumentsType, TQ_SIGNAL(activated(int)), TQ_SLOT(updateArguments()));
   container->addWidget(_argumentsType, 0,0, 1,1);
   label = new TQLabel(i18n("Arguments:"), container);
   container->addWidget(label, 1,1, 0,0);
@@ -46,19 +46,19 @@ ToolConfigWidget::ToolConfigWidget(Project *project)
   _arguments->setReadOnly(true);
   container->addWidget(_arguments, 1,1, 1,2);
   KPushButton *button = new KPushButton(KGuiItem(TQString(), "help"), container);
-  connect(button, TQT_SIGNAL(clicked()), TQT_SIGNAL(displayHelp()));
+  connect(button, TQ_SIGNAL(clicked()), TQ_SIGNAL(displayHelp()));
   container->addWidget(button, 1,1, 3,3);
   _argumentsEditor = new EditListBox(1, container, "arguments_editor", EditListBox::DuplicatesAllowed,
                                      EditListBox::Add | EditListBox::Remove | EditListBox::UpDown | EditListBox::RemoveAll | EditListBox::Reset);
-  connect(_argumentsEditor, TQT_SIGNAL(changed()), TQT_SLOT(updateArguments()));
-  connect(_argumentsEditor, TQT_SIGNAL(reset()), TQT_SLOT(resetCustomArguments()));
+  connect(_argumentsEditor, TQ_SIGNAL(changed()), TQ_SLOT(updateArguments()));
+  connect(_argumentsEditor, TQ_SIGNAL(reset()), TQ_SLOT(resetCustomArguments()));
   container->addWidget(_argumentsEditor, 2,2, 0,3);
 
   _container = new Container(container);
   _container->setColStretch(2, 1);
   container->addWidget(_container, 3,3, 0,3);
 
-  connect(this, TQT_SIGNAL(changed()), TQT_SLOT(updateArguments()));
+  connect(this, TQ_SIGNAL(changed()), TQ_SLOT(updateArguments()));
 }
 
 void ToolConfigWidget::init(Tool::Category category, const Tool::Group &group)
@@ -87,7 +87,7 @@ PURL::DirectoriesWidget *ToolConfigWidget::createDirectoriesEntry(const TQString
 {
   uint row = container()->numRows();
   PURL::DirectoriesWidget *sdw = new PURL::DirectoriesWidget(text, _project ? _project->directory().path() : TQString(), container());
-  connect(sdw, TQT_SIGNAL(changed()), TQT_SIGNAL(changed()));
+  connect(sdw, TQ_SIGNAL(changed()), TQ_SIGNAL(changed()));
   container()->addWidget(sdw, row,row, 0,2);
   return sdw;
 }
@@ -98,7 +98,7 @@ void ToolConfigWidget::createCustomOptionsEntry()
   TQLabel *label = new TQLabel(i18n("Custom options:"), container());
   container()->addWidget(label, row,row, 0,0);
   _customOptions = new TQLineEdit(container());
-  connect(_customOptions, TQT_SIGNAL(textChanged(const TQString &)), TQT_SIGNAL(changed()));
+  connect(_customOptions, TQ_SIGNAL(textChanged(const TQString &)), TQ_SIGNAL(changed()));
   container()->addWidget(_customOptions, row,row, 1,2);
 }
 
@@ -108,7 +108,7 @@ void ToolConfigWidget::createCustomLibrariesEntry()
   TQLabel *label = new TQLabel(i18n("Custom libraries:"), container());
   container()->addWidget(label, row,row, 0,0);
   _customLibraries = new TQLineEdit(container());
-  connect(_customLibraries, TQT_SIGNAL(textChanged(const TQString &)), TQT_SIGNAL(changed()));
+  connect(_customLibraries, TQ_SIGNAL(textChanged(const TQString &)), TQ_SIGNAL(changed()));
   TQToolTip::add(_customLibraries, i18n("<qt>This values will be placed after the linked objects.</qt>")) ;
   container()->addWidget(_customLibraries, row,row, 1,2);
 }
@@ -119,7 +119,7 @@ void ToolConfigWidget::createHexFormatEntry()
   TQLabel *label = new TQLabel(i18n("Hex file format:"), container());
   container()->addWidget(label, row,row, 0,0);
   _hexFormat = new TQComboBox(container());
-  connect(_hexFormat, TQT_SIGNAL(activated(int)), TQT_SIGNAL(changed()));
+  connect(_hexFormat, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
   for (uint i=0; i<HexBuffer::Nb_Formats; i++)
     _hexFormat->insertItem(HexBuffer::FORMATS[i]);
   _hexFormat->insertItem(i18n("as in LIST directive"));
