@@ -70,7 +70,7 @@ void Compile::FileData::List::cleanGenerated() const
 Compile::LogWidget::LogWidget(TQWidget *parent)
   : Log::Widget(parent, "compile_log")
 {
-  connect(this, TQT_SIGNAL(clicked(int, int)), TQT_SLOT(lineClicked(int)));
+  connect(this, TQ_SIGNAL(clicked(int, int)), TQ_SLOT(lineClicked(int)));
 }
 
 void Compile::LogWidget::clear()
@@ -95,7 +95,7 @@ void Compile::LogWidget::lineClicked(int line)
 {
   if ( !_map.contains(line) ) return;
   PURL::Url url = PURL::Url::fromPathOrUrl(_map[line].filepath);
-  TextEditor *e = ::tqqt_cast<TextEditor *>(Main::editorManager().openEditor(url));
+  TextEditor *e = ::tqt_cast<TextEditor *>(Main::editorManager().openEditor(url));
   if ( e==0 ) return;
   e->setCursor(_map[line].line, 0);
 }
@@ -124,10 +124,10 @@ bool Compile::BaseProcess::start()
   _stderr = TQString();
   delete _process;
   _process = new ::Process::LineSignal;
-  connect(_process, TQT_SIGNAL(done(int)), TQT_SLOT(done(int)));
-  connect(_process, TQT_SIGNAL(timeout()), TQT_SLOT(timeout()));
-  connect(_process, TQT_SIGNAL(logStdoutLine(const TQString &)), TQT_SLOT(logStdoutLine(const TQString &)));
-  connect(_process, TQT_SIGNAL(logStderrLine(const TQString &)), TQT_SLOT(logStderrLine(const TQString &)));
+  connect(_process, TQ_SIGNAL(done(int)), TQ_SLOT(done(int)));
+  connect(_process, TQ_SIGNAL(timeout()), TQ_SLOT(timeout()));
+  connect(_process, TQ_SIGNAL(logStdoutLine(const TQString &)), TQ_SLOT(logStdoutLine(const TQString &)));
+  connect(_process, TQ_SIGNAL(logStderrLine(const TQString &)), TQ_SLOT(logStderrLine(const TQString &)));
   _process->setWorkingDirectory(directory().path());
   setupProcess();
   _manager->log(Log::LineType::Command, _process->arguments().join(" "));
